@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.cpp,v 1.22.4.11 2004/08/12 10:27:14 chpe Exp $
+ *  $Id: EphyBrowser.cpp,v 1.22.4.12 2004/08/27 20:55:44 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -90,7 +90,7 @@
 #include "MozillaPrivate.h"
 #include "print-dialog.h"
 
-#if (MOZILLA_SNAPSHOT == 17) || (MOZILLA_SNAPSHOT >= 19)
+#if MOZILLA_SNAPSHOT >= 17
 #include "nsIDOMWindow2.h"
 #endif
 
@@ -258,7 +258,7 @@ EphyBrowser::GetListener (void)
   	nsCOMPtr<nsIDOMWindow> domWindowExternal;
   	mWebBrowser->GetContentDOMWindow(getter_AddRefs(domWindowExternal));
 
-#if (MOZILLA_SNAPSHOT == 17) || (MOZILLA_SNAPSHOT >= 19)
+#if MOZILLA_SNAPSHOT >= 17
 	nsCOMPtr<nsIDOMWindow2> domWindow (do_QueryInterface (domWindowExternal));
 	NS_ENSURE_TRUE (domWindow, NS_ERROR_FAILURE);
 
