@@ -220,8 +220,8 @@ GtkNSSClientAuthDialogs::ChooseCertificate (nsIInterfaceRequestor *ctx,
 	
 
 	const nsACString &utf8_cn = NS_ConvertUCS2toUTF8(cn);
-	tt_cn = g_strdup_printf ("\"<tt>%s</tt>\"", 
-				 PromiseFlatCString(utf8_cn).get());
+	tt_cn = g_markup_printf_escaped ("\"<tt>%s</tt>\"", 
+					 PromiseFlatCString(utf8_cn).get());
 
 	msg = g_strdup_printf (_("Choose a certificate to present as identification to %s."),
 			       tt_cn);
@@ -249,6 +249,7 @@ GtkNSSClientAuthDialogs::ChooseCertificate (nsIInterfaceRequestor *ctx,
 	}
 
 	combo = gtk_combo_box_new_with_model (GTK_TREE_MODEL (store));
+	g_object_unref (store);
 
         renderer = gtk_cell_renderer_text_new ();
         gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, TRUE);
