@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-single.cpp,v 1.69.4.2 2004/06/08 12:14:45 chpe Exp $
+ *  $Id: mozilla-embed-single.cpp,v 1.69.4.6 2004/08/27 20:55:44 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -76,6 +76,9 @@
 #include <nsIURI.h>
 #include <nsNetUtil.h>
 #include <nsIHttpAuthManager.h>
+#include <nsIPrintSettings.h>
+#include <nsIPrintSettingsService.h>
+#include <nsIPrintingPromptService.h>
 
 // FIXME: For setting the locale. hopefully gtkmozembed will do itself soon
 #include <nsIChromeRegistry.h>
@@ -419,11 +422,16 @@ mozilla_init_chrome (void)
 static void
 mozilla_init_observer (MozillaEmbedSingle *single)
 {
-	single->priv->mSingleObserver = new EphySingle ();
+	EphySingle *es;
 
-	if (single->priv->mSingleObserver)
+	es = new EphySingle ();
+	NS_ADDREF (single->priv->mSingleObserver = es);
+
+	nsresult rv;
+	rv = es->Init (EPHY_EMBED_SINGLE (single));
+	if (NS_FAILED (rv))
 	{
-		single->priv->mSingleObserver->Init (EPHY_EMBED_SINGLE (single));
+		g_warning ("Failed to initialised EphySingle!\n");
 	}
 }
 
@@ -496,6 +504,19 @@ mozilla_embed_single_init (MozillaEmbedSingle *mes)
 	}
 }
 
+static void
+mozilla_embed_single_dispose (GObject *object)
+{
+	MozillaEmbedSingle *single = MOZILLA_EMBED_SINGLE (object);
+
+	if (single->priv->mSingleObserver)
+	{
+		single->priv->mSingleObserver->Detach ();
+		NS_RELEASE (single->priv->mSingleObserver);
+		single->priv->mSingleObserver = nsnull;
+	}		
+}
+
 static void
 mozilla_embed_single_finalize (GObject *object)
 {
@@ -557,7 +578,11 @@ impl_load_proxy_autoconf (EphyEmbedSingle *shell,
                 do_GetService ("@mozilla.org/network/protocol-proxy-service;1");
 	if (!pps) return;
 
+#if MOZILLA_SNAPSHOT >= 20
+	pps->ConfigureFromPAC (nsDependentCString (url));
+#else
 	pps->ConfigureFromPAC (url);
+#endif
 }
 
 static GList *
@@ -591,6 +616,24 @@ impl_get_font_list (EphyEmbedSingle *shell,
 	return g_list_reverse (l);
 }
 
+static void
+impl_print_setup (EphyEmbedSingle *single)
+{
+	nsCOMPtr<nsIPrintSettingsService> pss
+		(do_GetService ("@mozilla.org/gfx/printsettings-service;1"));
+	if (!pss) return;
+
+	nsCOMPtr<nsIPrintSettings> settings;
+	pss->GetGlobalPrintSettings (getter_AddRefs (settings));
+	if (!settings) return;
+
+	nsCOMPtr<nsIPrintingPromptService> prompt
+		(do_GetService ("@mozilla.org/embedcomp/printingprompt-service;1"));
+	if (!prompt) return;
+
+	prompt->ShowPageSetup (nsnull, settings, nsnull);
+}
+
 static GList *
 impl_list_cookies (EphyCookieManager *manager)
 {
@@ -860,6 +903,7 @@ mozilla_embed_single_class_init (MozillaEmbedSingleClass *klass)
 
 	parent_class = (GObjectClass *) g_type_class_peek_parent (klass);
 
+	object_class->dispose = mozilla_embed_single_dispose;
 	object_class->finalize = mozilla_embed_single_finalize;
 
 	g_type_class_add_private (object_class, sizeof (MozillaEmbedSinglePrivate));
@@ -873,6 +917,7 @@ ephy_embed_single_iface_init (EphyEmbedSingleIface *iface)
 	iface->set_offline_mode = impl_set_offline_mode;
 	iface->load_proxy_autoconf = impl_load_proxy_autoconf;
 	iface->get_font_list = impl_get_font_list;
+	iface->print_setup = impl_print_setup;
 }
 
 static void
