@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks-export.c,v 1.14 2004/01/28 18:55:53 chpe Exp $
+ *  $Id: ephy-bookmarks-export.c,v 1.15 2004/02/12 16:59:27 chpe Exp $
  */
 
 #include "ephy-bookmarks-export.h"
@@ -100,6 +100,12 @@ ephy_bookmarks_export_rdf (EphyBookmarks *bookmarks,
 		return;
 	}
 
+	ret = xmlTextWriterSetIndent (writer, 1);
+	if (ret < 0) goto out;
+
+	ret = xmlTextWriterSetIndentString (writer, "  ");
+	if (ret < 0) goto out;
+	
 	ret = xmlTextWriterStartDocument (writer, "1.0", NULL, NULL);
 	if (ret < 0) goto out;
 
