@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.c,v 1.169.4.7 2004/06/13 08:32:53 chpe Exp $
+ *  $Id: ephy-window.c,v 1.169.4.11 2004/09/08 10:09:13 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -334,7 +334,6 @@ struct EphyWindowPrivate
 	GtkNotebook *notebook;
 	EphyTab *active_tab;
 	EphyDialog *find_dialog;
-	EphyDialog *print_dialog;
 	gboolean closing;
 	gboolean has_size;
 	guint num_tabs;
@@ -391,6 +390,33 @@ ephy_window_get_type (void)
         return ephy_window_type;
 }
 
+static void
+update_exit_fullscreen_popup_position (EphyWindow *window)
+{
+	GdkRectangle screen_rect;
+        int popup_height;
+
+        g_return_if_fail (window->priv->exit_fullscreen_popup != NULL);
+
+        gtk_window_get_size (GTK_WINDOW (window->priv->exit_fullscreen_popup),
+                             NULL, &popup_height);
+
+        gdk_screen_get_monitor_geometry (gdk_screen_get_default (),
+                        gdk_screen_get_monitor_at_window
+                        (gdk_screen_get_default (),
+                         GTK_WIDGET (window)->window),
+                         &screen_rect);
+
+        gtk_window_move (GTK_WINDOW (window->priv->exit_fullscreen_popup),
+                        screen_rect.x, screen_rect.height - popup_height);
+}
+
+static void
+size_changed_cb (GdkScreen *screen, EphyWindow *window)
+{
+	update_exit_fullscreen_popup_position (window);
+}
+
 static void
 ephy_window_destroy (GtkObject *gtkobject)
 {
@@ -411,6 +437,10 @@ ephy_window_destroy (GtkObject *gtkobject)
 
 	if (window->priv->exit_fullscreen_popup)
 	{
+		g_signal_handlers_disconnect_by_func
+			(gdk_screen_get_default (),
+			 G_CALLBACK (size_changed_cb), window);
+
 		gtk_widget_destroy (window->priv->exit_fullscreen_popup);
 		window->priv->exit_fullscreen_popup = NULL;
 	}
@@ -425,33 +455,6 @@ add_widget (GtkUIManager *merge, GtkWidget *widget, EphyWindow *window)
 			    widget, FALSE, FALSE, 0);
 }
 
-static void
-update_exit_fullscreen_popup_position (EphyWindow *window)
-{
-	GdkRectangle screen_rect;
-	int popup_height;
-
-	g_return_if_fail (window->priv->exit_fullscreen_popup != NULL);
-
-	gtk_window_get_size (GTK_WINDOW (window->priv->exit_fullscreen_popup),
-                             NULL, &popup_height);
-
-	gdk_screen_get_monitor_geometry (gdk_screen_get_default (),
-                        gdk_screen_get_monitor_at_window
-                        (gdk_screen_get_default (),
-                         GTK_WIDGET (window)->window),
-                         &screen_rect);
-
-	gtk_window_move (GTK_WINDOW (window->priv->exit_fullscreen_popup),
-                        screen_rect.x, screen_rect.height - popup_height);
-}
-
-static void
-size_changed_cb (GdkScreen *screen, EphyWindow *window)
-{
-	update_exit_fullscreen_popup_position (window);
-}
-
 static void
 exit_fullscreen_button_clicked_cb (GtkWidget *button, EphyWindow *window)
 {
@@ -675,7 +678,7 @@ ephy_window_delete_event_cb (GtkWidget *widget, GdkEvent *event, EphyWindow *win
 		EphyEmbed *embed;
 
 		embed = ephy_window_get_active_embed (window);
-		ephy_embed_print_preview_close (embed);
+		ephy_embed_set_print_preview_mode (embed, FALSE);
 
 		ephy_window_set_print_preview (window, FALSE);
 	}
@@ -2047,11 +2050,6 @@ ephy_window_finalize (GObject *object)
 		g_object_unref (G_OBJECT (window->priv->find_dialog));
 	}
 
-	if (window->priv->print_dialog)
-	{
-		g_object_unref (G_OBJECT (window->priv->print_dialog));
-	}
-
 	g_object_unref (window->priv->fav_menu);
 	g_object_unref (window->priv->enc_menu);
 	g_object_unref (window->priv->tabs_menu);
@@ -2322,7 +2320,6 @@ update_embed_dialogs (EphyWindow *window,
 {
 	EphyEmbed *embed;
 	EphyDialog *find_dialog = window->priv->find_dialog;
-	EphyDialog *print_dialog = window->priv->print_dialog;
 
 	embed = ephy_tab_get_embed (tab);
 
@@ -2332,13 +2329,6 @@ update_embed_dialogs (EphyWindow *window,
 			(EPHY_EMBED_DIALOG(find_dialog),
 			 embed);
 	}
-
-	if (print_dialog)
-	{
-		ephy_embed_dialog_set_embed
-			(EPHY_EMBED_DIALOG(print_dialog),
-			 embed);
-	}
 }
 
 static void
@@ -2386,48 +2376,6 @@ ephy_window_find (EphyWindow *window)
 	ephy_dialog_show (window->priv->find_dialog);
 }
 
-void
-ephy_window_print (EphyWindow *window)
-{
-	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINTING))
-	{
-		return;
-	}
-
-	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINT_SETUP) ||
-	    eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_COMMAND_LINE))
-	{
-		EphyEmbed *embed;
-		EmbedPrintInfo *info;
-
-		info = ephy_print_get_print_info ();
-
-		embed = ephy_window_get_active_embed (window);
-		g_return_if_fail (EPHY_IS_EMBED (embed));
-
-		ephy_embed_print (embed, info);
-
-		ephy_print_info_free (info);
-
-		return;
-	}
-
-	if (window->priv->print_dialog == NULL)
-	{
-		EphyDialog *dialog;
-		EphyEmbed *embed;
-
-		embed = ephy_window_get_active_embed (window);
-		dialog = ephy_print_dialog_new  (GTK_WIDGET (window), embed, FALSE);
-
-		window->priv->print_dialog = dialog;
-		g_object_add_weak_pointer(G_OBJECT (dialog),
-					  (gpointer *) &window->priv->print_dialog);
-	}
-
-	ephy_dialog_show (window->priv->print_dialog);
-}
-
 void
 ephy_window_set_zoom (EphyWindow *window,
 		      float zoom)
