@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ppview-toolbar.c,v 1.18 2003/11/30 11:38:12 marco Exp $
+ *  $Id: ppview-toolbar.c,v 1.18.4.1 2004/07/10 18:45:23 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -392,6 +392,6 @@ toolbar_cmd_ppv_close (GtkUIManager *merge,
 
 	ephy_window_set_print_preview (window, FALSE);
 
-	ephy_embed_print_preview_close (embed);
+	ephy_embed_set_print_preview_mode (embed, FALSE);
 }
 
